@@ -1,3 +1,7 @@
+from __future__ import unicode_literals
+
+import six
+
 import time
 from datetime import datetime, timedelta
 import unittest
@@ -7,6 +11,8 @@ from django.test.client import Client
 
 from unittest_data_provider import data_provider
 
+from session_security.utils import set_last_activity
+
 
 class ViewsTestCase(unittest.TestCase):
     def setUp(self):
@@ -16,9 +22,9 @@ class ViewsTestCase(unittest.TestCase):
         self.client.logout()
         self.client.get('/admin/')
         response = self.client.get('/session_security/ping/?idleFor=1')
-        self.assertEqual(response.content, 'logout')
+        self.assertEqual(response.content, six.b('logout'))
 
-    ping_provider = lambda: (
+    ping_provider = lambda x=None: (
         (1, 4, '1'),
         (3, 2, '2'),
         (5, 5, '5'),
@@ -32,10 +38,10 @@ class ViewsTestCase(unittest.TestCase):
 
         now = datetime.now()
         session = self.client.session
-        session['_session_security'] = now - timedelta(seconds=server)
+        set_last_activity(session, now - timedelta(seconds=server))
         session.save()
         response = self.client.get('/session_security/ping/?idleFor=%s' %
                                    client)
 
-        self.assertEqual(response.content, expected)
+        self.assertEqual(response.content, six.b(expected))
         self.assertEqual(authenticated, '_auth_user_id' in self.client.session)
