@@ -5,7 +5,7 @@ from datetime import datetime
 
 def set_last_activity(session, dt):
     """ Set the last activity datetime as a string in the session. """
-    session['_session_security'] = dt.isoformat()
+    session['_session_security'] = dt.strftime('%Y-%m-%dT%H:%M:%S.%f')
 
 
 def get_last_activity(session):
